@@ -14,7 +14,7 @@ def on_cli_init(func: T) -> T:
     """Register a function to run after the CLI has been initiated. Do nothing if the CLI has not been enabled.
 
     Args:
-        func: A callable that will receive the main `Group` as its first argument
+        func: A callable that will receive the main ``Group`` as its first argument
     """
 
     CLI_INIT_CALLBACKS.append(func)
